import { 
  select, 
  geoPath, 
  geoCentroid,
  geoNaturalEarth1,
  zoom, 
  event,
  scaleOrdinal,
  schemeSpectral,
  scaleSqrt,
  max,
  format
} from "d3";

import { loadAndProcessData } from "./loadAndProcessData";
import { sizeLegend } from "./sizeLegend";

const svg = select("svg");

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const radiusValue = d => d.properties["2018"];


const g = svg.append("g");

const colorLegendG = svg.append("g")
		.attr("transform", `translate(50, 300)`);
    
g.append("path")
	.attr("class", "sphere")
	.attr("d", pathGenerator({type: "Sphere"}));

svg.call(zoom().on("zoom", () => {
	g.attr("transform", event.transform);
}));

const populationFormat = format(",");

loadAndProcessData().then(countries => {

 	const sizeScale = scaleSqrt()
  		.domain([0, max(countries.features, radiusValue)])
  		.range([0, 30]);

  g.selectAll("path").data(countries.features)	
  		.enter().append("path")
  			.attr("class", "country")
  			.attr("d", pathGenerator)
  			.attr("fill", d => d.properties["2018"] ? "#d6d6d6" : "#fec1c1")
  		.append("title")
  			.text(d => isNaN(radiusValue(d)) 
          ? "Missing Data"
          :[
    				d.properties["Region, subregion, country or area *"],
    				populationFormat(radiusValue(d))
  				].join(": "));
  
  countries.featuresWithPopulation.forEach(d => {
  	d.properties.projected = projection(geoCentroid(d));
  });
  
  g.selectAll("circle").data(countries.featuresWithPopulation)	
  		.enter().append("circle")
  			.attr("class", "country-circle")
  			.attr("cx", d => d.properties.projected[0])
  			.attr("cy", d => d.properties.projected[1])
  			.attr("r", d => sizeScale(radiusValue(d)));

	g.append("g")
		.attr("transform", `translate(70, 200)`)
    .call(sizeLegend, {
      sizeScale,
  		spacing: 45,
  		textOffset: 20,
  		numTicks: 5,
    	tickFormat: populationFormat
	})
  	.append("text")
  	.attr("class", "legend-title")
  	.text("Population")
  	.attr("y", -40);
});



// use d.name for name
// use d.iso_n3 for id

